Crate branchia

Crate branchia 

Re-exports

pub use keypair::KeypairExt;
pub use rpc::Rpc;
pub use solana_client::SolanaClient;
pub use transaction::TxBuilder;
pub use transaction::MetadataArgs;

Modules

keypair
rpc
solana_client
transaction
utils

Structs

CommitmentConfig
Keypair
A vanilla Ed25519 key pair
Rent
Configuration of network rent.

Constants

TOKEN_2022_PROGRAM_ADDRESS
The const program ID.
TOKEN_PROGRAM_ADDRESS
The const program ID.

Traits

Signer
The Signer trait declares operations that all digital signature providers must support. It is the primary interface by which signers are specified in Transaction signing interfaces