Re-exports
pub use keypair::KeypairExt;pub use rpc::Rpc;pub use solana_client::SolanaClient;pub use transaction::TxBuilder;pub use transaction::MetadataArgs;
Modules
Structs
- Commitment
Config - Keypair
- A vanilla Ed25519 key pair
- Rent
- Configuration of network rent.
Constants
- TOKEN_
2022_ PROGRAM_ ADDRESS - The const program ID.
- TOKEN_
PROGRAM_ ADDRESS - The const program ID.
Traits
- Signer
- The
Signertrait declares operations that all digital signature providers must support. It is the primary interface by which signers are specified inTransactionsigning interfaces